searchData={"items":[{"type":"module","title":"JWT","doc":"Encode claims for transmission as a JSON object that is used as the payload of a JSON Web\nSignature (JWS) structure, enabling the claims to be integrity protected with a Message\nAuthentication Code (MAC), to be later verified\n\nsee http://tools.ietf.org/html/rfc7519","ref":"JWT.html"},{"type":"function","title":"JWT.sign/2","doc":"Return a JSON Web Token (JWT), a string representing a set of claims as a JSON object that is\nencoded in a JWS","ref":"JWT.html#sign/2"},{"type":"function","title":"Example - JWT.sign/2","doc":"iex> claims = %{iss: \"joe\", exp: 1300819380, \"http://example.com/is_root\": true}\n    ...> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.sign(claims, key: key)\n    \"eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjEzMDA4MTkzODAsImh0dHA6Ly9leGFtcGxlLmNvbS9pc19yb290Ijp0cnVlLCJpc3MiOiJqb2UifQ.C5kby-t7W1CM1VB_avPCCHbtOXsNsywYAKYex8rHZh8\"\n\nsee http://tools.ietf.org/html/rfc7519#section-7.1","ref":"JWT.html#sign/2-example"},{"type":"function","title":"JWT.unify_header/1","doc":"Given an options map, return a map of header options","ref":"JWT.html#unify_header/1"},{"type":"function","title":"Example - JWT.unify_header/1","doc":"iex> JWT.unify_header(alg: \"RS256\", key: \"key\")\n    %{typ: \"JWT\", alg: \"RS256\"}\n\nFilters out unsupported claims options and ignores any encryption keys","ref":"JWT.html#unify_header/1-example"},{"type":"function","title":"JWT.verify/2","doc":"Return a tuple {:ok, claims (map)} if the JWT signature is verified,\nor {:error, exception} otherwise","ref":"JWT.html#verify/2"},{"type":"function","title":"Example - JWT.verify/2","doc":"iex> jwt =\"eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJuYW1lIjoiam9lIiwiaHR0cDovL2V4YW1wbGUuY29tL2lzX3Jvb3QiOnRydWUsImRhdGV0aW1lIjoxMzAwODE5MzgwfQ.8CbXtOJ51MfPLlNTDpMMBHExFZGmqIC2c_hjuY0Dp24\"\n    ...> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.verify(jwt, %{key: key})\n    {:ok, %{\"name\" => \"joe\", \"datetime\" => 1300819380, \"http://example.com/is_root\" => true}}\n    iex> jwt =\"eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJuYW1lIjoiam9lIiwiaHR0cDovL2V4YW1wbGUuY29tL2lzX3Jvb3QiOnRydWUsImRhdGV0aW1lIjoxMzAwODE5MzgwfQ.8CbXtOJ51MfPLlNTDpMMBHExFZGmqIC2c_hjuY0Dp24\"\n    ...> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.verify(jwt, %{key: key, decode: [keys: :atoms]})\n    {:ok, %{datetime: 1300819380, \"http://example.com/is_root\": true, name: \"joe\"}}\n\nsee http://tools.ietf.org/html/rfc7519#section-7.2","ref":"JWT.html#verify/2-example"},{"type":"function","title":"JWT.verify!/2","doc":"","ref":"JWT.html#verify!/2"},{"type":"module","title":"JWT.Algorithm.Ecdsa","doc":"Sign or verify a JSON Web Signature (JWS) structure using EDCSA\n\nsee http://tools.ietf.org/html/rfc7518#section-3.4","ref":"JWT.Algorithm.Ecdsa.html"},{"type":"function","title":"JWT.Algorithm.Ecdsa.curve/1","doc":"Named curve corresponding to sha_bits","ref":"JWT.Algorithm.Ecdsa.html#curve/1"},{"type":"function","title":"JWT.Algorithm.Ecdsa.sign/3","doc":"Return a der-encoded digital signature, or Message Authentication Code (MAC)","ref":"JWT.Algorithm.Ecdsa.html#sign/3"},{"type":"function","title":"Example - JWT.Algorithm.Ecdsa.sign/3","doc":"iex> {_, private_key} = EcdsaUtil.key_pair\n    ...> der_encoded_mac = JWT.Algorithm.Ecdsa.sign(:sha256, private_key, \"signing_input\")\n    ...> byte_size(der_encoded_mac) > 69\n    true","ref":"JWT.Algorithm.Ecdsa.html#sign/3-example"},{"type":"function","title":"JWT.Algorithm.Ecdsa.verify?/4","doc":"Predicate to verify a der-encoded digital signature, or Message Authentication Code (MAC)","ref":"JWT.Algorithm.Ecdsa.html#verify?/4"},{"type":"function","title":"Example - JWT.Algorithm.Ecdsa.verify?/4","doc":"iex> {public_key, private_key} = JWT.Algorithm.EcdsaUtil.key_pair\n    ...> mac = JWT.Algorithm.Ecdsa.sign(:sha256, private_key, \"signing_input\")\n    ...> JWT.Algorithm.Ecdsa.verify?(mac, :sha256, public_key, \"signing_input\")\n    true","ref":"JWT.Algorithm.Ecdsa.html#verify?/4-example"},{"type":"module","title":"JWT.Algorithm.EcdsaUtil","doc":"Encryption keys for test","ref":"JWT.Algorithm.EcdsaUtil.html"},{"type":"function","title":"JWT.Algorithm.EcdsaUtil.key_pair/1","doc":"Generate an Ecdsa {public_key, private_key} tuple","ref":"JWT.Algorithm.EcdsaUtil.html#key_pair/1"},{"type":"module","title":"JWT.Algorithm.Hmac","doc":"Sign or verify a JSON Web Signature (JWS) structure using HMAC with SHA-2 algorithms\n\nsee http://tools.ietf.org/html/rfc7518#section-3.2","ref":"JWT.Algorithm.Hmac.html"},{"type":"function","title":"JWT.Algorithm.Hmac.sign/3","doc":"Return a Message Authentication Code (MAC)","ref":"JWT.Algorithm.Hmac.html#sign/3"},{"type":"function","title":"Example - JWT.Algorithm.Hmac.sign/3","doc":"iex> shared_key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.Algorithm.Hmac.sign(:sha256, shared_key, \"signing_input\")\n    <<90, 34, 44, 252, 147, 130, 167, 173, 86, 191, 247, 93, 94, 12, 200, 30, 173, 115, 248, 89, 246, 222, 4, 213, 119, 74, 70, 20, 231, 194, 104, 103>>","ref":"JWT.Algorithm.Hmac.html#sign/3-example"},{"type":"function","title":"JWT.Algorithm.Hmac.verify?/4","doc":"Predicate to verify the signing_input by comparing a given `mac` to the `mac` for a newly\nsigned message; comparison done in a constant-time manner to thwart timing attacks","ref":"JWT.Algorithm.Hmac.html#verify?/4"},{"type":"function","title":"Example - JWT.Algorithm.Hmac.verify?/4","doc":"iex> mac = <<90, 34, 44, 252, 147, 130, 167, 173, 86, 191, 247, 93, 94, 12, 200, 30, 173, 115, 248, 89, 246, 222, 4, 213, 119, 74, 70, 20, 231, 194, 104, 103>>\n    ...> shared_key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.Algorithm.Hmac.verify?(mac, :sha256, shared_key, \"signing_input\")\n    true","ref":"JWT.Algorithm.Hmac.html#verify?/4-example"},{"type":"module","title":"JWT.Algorithm.Rsa","doc":"Sign or verify a JSON Web Signature (JWS) structure using RSASSA-PKCS-v1_5\n\nsee http://tools.ietf.org/html/rfc7518#section-3.3","ref":"JWT.Algorithm.Rsa.html"},{"type":"function","title":"JWT.Algorithm.Rsa.modulus/1","doc":"RSA key modulus, n","ref":"JWT.Algorithm.Rsa.html#modulus/1"},{"type":"function","title":"JWT.Algorithm.Rsa.sign/3","doc":"Return a Message Authentication Code (MAC)","ref":"JWT.Algorithm.Rsa.html#sign/3"},{"type":"function","title":"Example - JWT.Algorithm.Rsa.sign/3","doc":"iex> alias JWT.Algorithm.RsaUtil\n    ...> private_key = RsaUtil.private_key(\"test/fixtures/rsa\", \"private_key.pem\")\n    ...> mac = JWT.Algorithm.Rsa.sign(:sha256, private_key, \"signing_input\")\n    ...> byte_size(mac)\n    256","ref":"JWT.Algorithm.Rsa.html#sign/3-example"},{"type":"function","title":"JWT.Algorithm.Rsa.verify?/4","doc":"Predicate to verify a digital signature, or mac","ref":"JWT.Algorithm.Rsa.html#verify?/4"},{"type":"function","title":"Example - JWT.Algorithm.Rsa.verify?/4","doc":"iex> alias JWT.Algorithm.RsaUtil\n    ...> path_to_keys = \"test/fixtures/rsa\"\n    ...> private_key = RsaUtil.private_key(path_to_keys, \"private_key.pem\")\n    ...> public_key = RsaUtil.public_key(path_to_keys, \"public_key.pem\")\n    ...> mac = JWT.Algorithm.Rsa.sign(:sha256, private_key, \"signing_input\")\n    ...> JWT.Algorithm.Rsa.verify?(mac, :sha256, public_key, \"signing_input\")\n    true","ref":"JWT.Algorithm.Rsa.html#verify?/4-example"},{"type":"module","title":"JWT.Algorithm.RsaUtil","doc":"Encryption keys for test","ref":"JWT.Algorithm.RsaUtil.html"},{"type":"function","title":"JWT.Algorithm.RsaUtil.private_key/1","doc":"Load an RSA private key from a string","ref":"JWT.Algorithm.RsaUtil.html#private_key/1"},{"type":"function","title":"JWT.Algorithm.RsaUtil.private_key/2","doc":"Load an RSA private key from a pem file","ref":"JWT.Algorithm.RsaUtil.html#private_key/2"},{"type":"function","title":"JWT.Algorithm.RsaUtil.public_key/1","doc":"Load an RSA public key from a string","ref":"JWT.Algorithm.RsaUtil.html#public_key/1"},{"type":"function","title":"JWT.Algorithm.RsaUtil.public_key/2","doc":"Load an RSA public key from a pem file","ref":"JWT.Algorithm.RsaUtil.html#public_key/2"},{"type":"module","title":"JWT.Algorithm.SHA","doc":"Common algorithm sha_bits validation","ref":"JWT.Algorithm.SHA.html"},{"type":"function","title":"JWT.Algorithm.SHA.fetch_length!/1","doc":"","ref":"JWT.Algorithm.SHA.html#fetch_length!/1"},{"type":"macro","title":"JWT.Algorithm.SHA.valid?/1","doc":"","ref":"JWT.Algorithm.SHA.html#valid?/1"},{"type":"module","title":"JWT.Claim","doc":"Verify JSON Web Token (JWT) claims\n\nsee http://tools.ietf.org/html/rfc7519#section-4.1","ref":"JWT.Claim.html"},{"type":"function","title":"JWT.Claim.verify/2","doc":"Collect JWT claims that fail validation","ref":"JWT.Claim.html#verify/2"},{"type":"function","title":"Example - JWT.Claim.verify/2","doc":"iex> seconds = DateTime.to_unix(DateTime.utc_now) + 1\n    ...> claims = %{\"exp\" => seconds}\n    ...> JWT.Claim.verify(claims, %{})\n    :ok\n\n    iex> claims = %{\"aud\" => \"Someone else\"}\n    ...> JWT.Claim.verify(claims, %{aud: \"You\"})\n    {:error, [aud: \"Someone else\"]}\n\nReturns a list containing any registered claims that fail validation","ref":"JWT.Claim.html#verify/2-example"},{"type":"module","title":"JWT.Claim.Aud","doc":"Audience\n\nsee http://tools.ietf.org/html/rfc7519#section-4.1.3","ref":"JWT.Claim.Aud.html"},{"type":"function","title":"JWT.Claim.Aud.reject?/2","doc":"Predicate to reject an audience claim value that does not include the recipient","ref":"JWT.Claim.Aud.html#reject?/2"},{"type":"function","title":"Example - JWT.Claim.Aud.reject?/2","doc":"iex> recipient = \"recipient\"\n    ...> aud = [recipient]\n    ...> Aud.reject?(aud, %{aud: recipient})\n    false\n\nReturns `true` or `false`","ref":"JWT.Claim.Aud.html#reject?/2-example"},{"type":"module","title":"JWT.Claim.Exp","doc":"Expiration time\n\nsee http://tools.ietf.org/html/rfc7519#section-4.1.4","ref":"JWT.Claim.Exp.html"},{"type":"function","title":"JWT.Claim.Exp.reject?/2","doc":"Predicate to reject an expiration time claim value equal to or before the current time","ref":"JWT.Claim.Exp.html#reject?/2"},{"type":"function","title":"Example - JWT.Claim.Exp.reject?/2","doc":"iex> seconds = DateTime.to_unix(DateTime.utc_now) + 1\n    ...> Exp.reject?(seconds, %{})\n    false\n\nReturns `true` if the current time is after `numeric_date`; otherwise returns `false`\n\n`numeric_date` is the number of seconds from the Unix Epoch (1970-01-01T00:00:00Z UTC)\nuntil the specified UTC date/time; non-integer values may be used","ref":"JWT.Claim.Exp.html#reject?/2-example"},{"type":"module","title":"JWT.Claim.Iat","doc":"Issued at\n\nsee http://tools.ietf.org/html/rfc7519#section-4.1.6","ref":"JWT.Claim.Iat.html"},{"type":"function","title":"JWT.Claim.Iat.reject?/2","doc":"Predicate to reject an issued_at time claim value equal to or after the current time","ref":"JWT.Claim.Iat.html#reject?/2"},{"type":"function","title":"Example - JWT.Claim.Iat.reject?/2","doc":"iex> seconds = DateTime.to_unix(DateTime.utc_now) - 1\n    ...> Iat.reject?(seconds, %{})\n    false\n\nReturns `false` if the current time is after `numeric_date`; otherwise returns `true`\n\n`numeric_date` is the number of seconds from the Unix Epoch (1970-01-01T00:00:00Z UTC)\nuntil the specified UTC date/time; non-integer values may be used","ref":"JWT.Claim.Iat.html#reject?/2-example"},{"type":"module","title":"JWT.Claim.Iss","doc":"Issuer\n\nsee http://tools.ietf.org/html/rfc7519#section-4.1.1","ref":"JWT.Claim.Iss.html"},{"type":"function","title":"JWT.Claim.Iss.reject?/2","doc":"Predicate to reject an iss claim that does not match the expected issuer","ref":"JWT.Claim.Iss.html#reject?/2"},{"type":"function","title":"Example - JWT.Claim.Iss.reject?/2","doc":"iex> Iss.reject?(\"issuer\", %{iss: \"other issuer\"})\n    true\n\nReturns `true` or `false`","ref":"JWT.Claim.Iss.html#reject?/2-example"},{"type":"module","title":"JWT.Claim.Jti","doc":"JWT ID\n\nsee http://tools.ietf.org/html/rfc7519#section-4.1.7","ref":"JWT.Claim.Jti.html"},{"type":"function","title":"JWT.Claim.Jti.reject?/2","doc":"Predicate to reject a jti claim that does not match the expected JTI","ref":"JWT.Claim.Jti.html#reject?/2"},{"type":"function","title":"Example - JWT.Claim.Jti.reject?/2","doc":"iex> Jti.reject?(\"jwt_id\", %{iss: \"other jwt_id\"})\n    true\n\nReturns `true` or `false`","ref":"JWT.Claim.Jti.html#reject?/2-example"},{"type":"module","title":"JWT.Claim.Nbf","doc":"Not before\n\nsee http://tools.ietf.org/html/rfc7519#section-4.1.5","ref":"JWT.Claim.Nbf.html"},{"type":"function","title":"JWT.Claim.Nbf.reject?/2","doc":"Predicate to reject an expiration time claim value equal to or before the current time","ref":"JWT.Claim.Nbf.html#reject?/2"},{"type":"function","title":"Example - JWT.Claim.Nbf.reject?/2","doc":"iex> seconds = DateTime.to_unix(DateTime.utc_now) - 1\n    ...> Nbf.reject?(seconds, %{})\n    false\n\nReturns `true` if the current time is before `numeric_date`; otherwise returns `false`\n\n`numeric_date` is the number of seconds from the Unix Epoch (1970-01-01T00:00:00Z UTC)\nuntil the specified UTC date/time; non-integer values may be used","ref":"JWT.Claim.Nbf.html#reject?/2-example"},{"type":"module","title":"JWT.Coding","doc":"","ref":"JWT.Coding.html"},{"type":"function","title":"JWT.Coding.decode/2","doc":"","ref":"JWT.Coding.html#decode/2"},{"type":"function","title":"JWT.Coding.decode!/2","doc":"","ref":"JWT.Coding.html#decode!/2"},{"type":"function","title":"JWT.Coding.encode!/1","doc":"","ref":"JWT.Coding.html#encode!/1"},{"type":"module","title":"JWT.Jwa","doc":"Choose a cryptographic algorithm to be used for a JSON Web Signature (JWS)\n\nsee http://tools.ietf.org/html/rfc7518","ref":"JWT.Jwa.html"},{"type":"function","title":"JWT.Jwa.destructured_alg/1","doc":"Return a tuple with a valid encryption module and sha_bits; raise if `string` is not a supported algorithm","ref":"JWT.Jwa.html#destructured_alg/1"},{"type":"function","title":"Example - JWT.Jwa.destructured_alg/1","doc":"iex> JWT.Jwa.destructured_alg(\"HS256\")\n    {JWT.Algorithm.Hmac, :sha256}","ref":"JWT.Jwa.html#destructured_alg/1-example"},{"type":"function","title":"JWT.Jwa.sign/3","doc":"Return a Message Authentication Code (MAC) for a particular `algorithm`","ref":"JWT.Jwa.html#sign/3"},{"type":"function","title":"Example - JWT.Jwa.sign/3","doc":"iex> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.Jwa.sign(\"HS256\", key, \"signing_input\")\n    <<90, 34, 44, 252, 147, 130, 167, 173, 86, 191, 247, 93, 94, 12, 200, 30, 173, 115, 248, 89, 246, 222, 4, 213, 119, 74, 70, 20, 231, 194, 104, 103>>","ref":"JWT.Jwa.html#sign/3-example"},{"type":"function","title":"JWT.Jwa.verify?/4","doc":"Predicate to validate that `mac` does verify by `algorithm`","ref":"JWT.Jwa.html#verify?/4"},{"type":"function","title":"Example - JWT.Jwa.verify?/4","doc":"iex> mac = <<90, 34, 44, 252, 147, 130, 167, 173, 86, 191, 247, 93, 94, 12, 200, 30, 173, 115, 248, 89, 246, 222, 4, 213, 119, 74, 70, 20, 231, 194, 104, 103>>\n    ...> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.Jwa.verify?(mac, \"HS256\", key, \"signing_input\")\n    true","ref":"JWT.Jwa.html#verify?/4-example"},{"type":"module","title":"JWT.Jws","doc":"Represent content to be secured with digital signatures or Message Authentication Codes (MACs)\n\nsee http://tools.ietf.org/html/rfc7515","ref":"JWT.Jws.html"},{"type":"function","title":"JWT.Jws.sign/3","doc":"Return a JSON Web Signature (JWS), a string representing a digitally signed payload","ref":"JWT.Jws.html#sign/3"},{"type":"function","title":"Example - JWT.Jws.sign/3","doc":"iex> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.Jws.sign(%{alg: \"HS256\"}, \"payload\", key)\n    \"eyJhbGciOiJIUzI1NiJ9.cGF5bG9hZA.uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"","ref":"JWT.Jws.html#sign/3-example"},{"type":"function","title":"JWT.Jws.unsecured_message/2","doc":"Return a JWS that provides no integrity protection (i.e. lacks a signature)","ref":"JWT.Jws.html#unsecured_message/2"},{"type":"function","title":"Example - JWT.Jws.unsecured_message/2","doc":"iex> JWT.Jws.unsecured_message(%{alg: \"none\"}, \"payload\")\n    \"eyJhbGciOiJub25lIn0.cGF5bG9hZA.\"\n\nsee http://tools.ietf.org/html/rfc7515#page-47","ref":"JWT.Jws.html#unsecured_message/2-example"},{"type":"function","title":"JWT.Jws.verify/3","doc":"Return a tuple {:ok, jws_parts} if the signature is verified, or {:error, exception} otherwise","ref":"JWT.Jws.html#verify/3"},{"type":"function","title":"Example - JWT.Jws.verify/3","doc":"iex> jws = \"eyJhbGciOiJIUzI1NiJ9.cGF5bG9hZA.uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"\n    ...> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.Jws.verify(jws, \"HS256\", key)\n    {:ok, [\"eyJhbGciOiJIUzI1NiJ9\", \"cGF5bG9hZA\", \"uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"]}\n\n    iex> jws = \"eyJhbGciOiJIUzI1NiJ9.cGF5bG9hZA.uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"\n    ...> key = \"invalid-key-invalid-key-invalid-key\"\n    ...> JWT.Jws.verify(jws, \"HS256\", key)\n    {:error, JWT.InvalidSignatureError}\n\n    iex> jws = \"eyJhbGciOiJIUzI1NiJ9.modified-content.uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"\n    ...> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.Jws.verify(jws, \"HS256\", key)\n    {:error, JWT.InvalidSignatureError}\n\n    iex> jws = \"eyJhb%%%%%%%%%%%%%%%.cGF5bG9hZA.uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"\n    ...> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.Jws.verify(jws, \"HS256\", key)\n    {:error, JWT.DecodeError}\n\n    iex> jws = \"eyJhbGciOiJIUzI1NiJ9.uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"\n    ...> key = nil\n    ...> JWT.Jws.verify(jws, \"HS256\", key)\n    {:error, JWT.MissingKeyError}\n\n    iex> jws = \"eyJhbGciOiJIUzI1NiJ9.cGF5bG9hZA.uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"\n    ...> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.Jws.verify(jws, \"%%%%%\", key)\n    {:error, JWT.UnmatchedAlgorithmError}","ref":"JWT.Jws.html#verify/3-example"},{"type":"function","title":"JWT.Jws.verify!/3","doc":"Return jws parts if the signature is verified, raises error otherwise","ref":"JWT.Jws.html#verify!/3"},{"type":"function","title":"Example - JWT.Jws.verify!/3","doc":"iex> jws = \"eyJhbGciOiJIUzI1NiJ9.cGF5bG9hZA.uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"\n    ...> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.Jws.verify!(jws, \"HS256\", key)\n    [\"eyJhbGciOiJIUzI1NiJ9\", \"cGF5bG9hZA\", \"uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"]\n\n    iex> jws = \"eyJhbGciOiJIUzI1NiJ9.cGF5bG9hZA.uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"\n    ...> key = \"invalid-key-invalid-key-invalid-key\"\n    ...> JWT.Jws.verify!(jws, \"HS256\", key)\n    ** (JWT.InvalidSignatureError) Invalid Signature\n\n    iex> jws = \"eyJhbGciOiJIUzI1NiJ9.modified-content.uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"\n    ...> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.Jws.verify!(jws, \"HS256\", key)\n    ** (JWT.InvalidSignatureError) Invalid Signature\n\n    iex> jws = \"eyJhb%%%%%%%%%%%%%%%.cGF5bG9hZA.uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"\n    ...> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.Jws.verify!(jws, \"HS256\", key)\n    ** (JWT.DecodeError) Failed to decode base64 string\n\n    iex> jws = \"eyJhbGciOiJIUzI1NiJ9.uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"\n    ...> key = nil\n    ...> JWT.Jws.verify!(jws, \"HS256\", key)\n    ** (JWT.MissingKeyError) Key is required for all algorithms but 'none'\n\n    iex> jws = \"eyJhbGciOiJIUzI1NiJ9.cGF5bG9hZA.uVTaOdyzp_f4mT_hfzU8LnCzdmlVC4t2itHDEYUZym4\"\n    ...> key = \"gZH75aKtMN3Yj0iPS4hcgUuTwjAzZr9C\"\n    ...> JWT.Jws.verify!(jws, \"%%%%%\", key)\n    ** (JWT.UnmatchedAlgorithmError) Algorithm not matching 'alg' header parameter","ref":"JWT.Jws.html#verify!/3-example"},{"type":"exception","title":"JWT.ClaimValidationError","doc":"","ref":"JWT.ClaimValidationError.html"},{"type":"exception","title":"JWT.DecodeError","doc":"","ref":"JWT.DecodeError.html"},{"type":"exception","title":"JWT.InvalidSignatureError","doc":"","ref":"JWT.InvalidSignatureError.html"},{"type":"exception","title":"JWT.MissingKeyError","doc":"","ref":"JWT.MissingKeyError.html"},{"type":"exception","title":"JWT.SecurityError","doc":"","ref":"JWT.SecurityError.html"},{"type":"exception","title":"JWT.UnmatchedAlgorithmError","doc":"","ref":"JWT.UnmatchedAlgorithmError.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}